==> haskell-optics-extra-0.4.2.1-233-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optics-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 optics-extra
version:              0.4.2.1
visibility:           public
id:                   optics-extra-0.4.2.1-E7UmXusZcKLK8BiYuLoaQX
key:                  optics-extra-0.4.2.1-E7UmXusZcKLK8BiYuLoaQX
license:              BSD-3-Clause
maintainer:           optics@well-typed.com
author:               Andrzej Rybczak
synopsis:             Extra utilities and instances for optics-core
description:
    This package provides extra definitions and instances that extend the
    @<https://hackage.haskell.org/package/optics-core optics-core>@ package,
    without incurring too many dependencies.  See the
    @<https://hackage.haskell.org/package/optics optics>@ package for more
    documentation.

category:             Data, Optics, Lenses
abi:                  22d29cc7cbb29d0ef6882a0562cbc005
exposed:              True
exposed-modules:
    Data.ByteString.Lazy.Optics Data.ByteString.Optics
    Data.ByteString.Strict.Optics Data.HashMap.Optics
    Data.HashSet.Optics Data.Text.Lazy.Optics Data.Text.Optics
    Data.Text.Strict.Optics Data.Vector.Generic.Optics
    Data.Vector.Optics Optics.At Optics.Cons Optics.Each Optics.Empty
    Optics.Extra Optics.Extra.Internal.ByteString
    Optics.Extra.Internal.Vector Optics.Extra.Internal.Zoom
    Optics.Indexed Optics.Passthrough Optics.State
    Optics.State.Operators Optics.View Optics.Zoom

import-dirs:          /usr/lib/ghc-9.4.8/site-local/optics-extra-0.4.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/optics-extra-0.4.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/optics-extra-0.4.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optics-extra
hs-libraries:         HSoptics-extra-0.4.2.1-E7UmXusZcKLK8BiYuLoaQX
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.6.0-Bdyeh8ev81I2bBqnptAVUL
    indexed-profunctors-0.1.1.1-22C7gA3HhCjKgNsu9Fnn18
    indexed-traversable-instances-0.1.2-1w6ZeCYO78G5hWeuJsG2bl
    mtl-2.2.2 optics-core-0.4.1.1-CR9FKpPQYOw8WAQKAI7qy2 text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-1s4f8pAJmee27mGfYrIk99
    vector-0.13.2.0-JPy5pohpq8EDknIfFhMz6E

haddock-interfaces:
    /usr/share/doc/haskell-optics-extra/html/optics-extra.haddock

haddock-html:         /usr/share/doc/haskell-optics-extra/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optics-extra-0.4.2.1-234-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-optics-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 optics-extra
version:              0.4.2.1
visibility:           public
id:                   optics-extra-0.4.2.1-EmARVy8ieusH4taZe5TqT9
key:                  optics-extra-0.4.2.1-EmARVy8ieusH4taZe5TqT9
license:              BSD-3-Clause
maintainer:           optics@well-typed.com
author:               Andrzej Rybczak
synopsis:             Extra utilities and instances for optics-core
description:
    This package provides extra definitions and instances that extend the
    @<https://hackage.haskell.org/package/optics-core optics-core>@ package,
    without incurring too many dependencies.  See the
    @<https://hackage.haskell.org/package/optics optics>@ package for more
    documentation.

category:             Data, Optics, Lenses
abi:                  365d7a8b90c77d9c83e3ed757cba792b
exposed:              True
exposed-modules:
    Data.ByteString.Lazy.Optics Data.ByteString.Optics
    Data.ByteString.Strict.Optics Data.HashMap.Optics
    Data.HashSet.Optics Data.Text.Lazy.Optics Data.Text.Optics
    Data.Text.Strict.Optics Data.Vector.Generic.Optics
    Data.Vector.Optics Optics.At Optics.Cons Optics.Each Optics.Empty
    Optics.Extra Optics.Extra.Internal.ByteString
    Optics.Extra.Internal.Vector Optics.Extra.Internal.Zoom
    Optics.Indexed Optics.Passthrough Optics.State
    Optics.State.Operators Optics.View Optics.Zoom

import-dirs:          /usr/lib/ghc-9.4.8/site-local/optics-extra-0.4.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/optics-extra-0.4.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/optics-extra-0.4.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optics-extra
hs-libraries:         HSoptics-extra-0.4.2.1-EmARVy8ieusH4taZe5TqT9
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.6.0-2hEv5lQFD6LEJdTUNcXkaI
    indexed-profunctors-0.1.1.1-22C7gA3HhCjKgNsu9Fnn18
    indexed-traversable-instances-0.1.2-3pG88dmm88A7tO5KE4WjhJ
    mtl-2.2.2 optics-core-0.4.1.1-EQqdiMTyppaITRJXyIj40k text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-Jnp6Xrk1NDm4qrPXFyeyaF
    vector-0.13.2.0-HGgKaKiJszd4ty04a0OkB8

haddock-interfaces:
    /usr/share/doc/haskell-optics-extra/html/optics-extra.haddock

haddock-html:         /usr/share/doc/haskell-optics-extra/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
